@@ -42,13 +42,13 @@ impl IsotonicRegression {
     }
 
     /// Find the _y_ point at position `at_x`
-    pub fn interpolate(&self, at_x: &f64) -> f64 {
+    pub fn interpolate(&self, at_x: f64) -> f64 {
         if self.points.len() == 1 {
             return self.points[0].y;
         } else {
             let pos = self
                 .points
-                .binary_search_by_key(&OrderedFloat(*at_x), |p| OrderedFloat(p.x));
+                .binary_search_by_key(&OrderedFloat(at_x), |p| OrderedFloat(p.x));
             return match pos {
                 Ok(ix) => self.points[ix].y,
                 Err(ix) => {
@@ -170,6 +170,20 @@ fn isotonic(points: &[Point], direction: Direction) -> Vec<Point> {
 mod tests {
     use super::*;
 
+    #[test]
+    fn usage_example() {
+        let points = &[
+            Point::new(0.0, 1.0),
+            Point::new(1.0, 2.0),
+            Point::new(2.0, 1.5),
+        ];
+
+        let regression = IsotonicRegression::new_ascending(points);
+        assert_eq!(
+            regression.interpolate(1.5), 1.75
+        );
+    }
+
     #[test]
     fn isotonic_no_points() {
         assert_eq!(isotonic(&[], Direction::Ascending).is_empty(), true);
@@ -285,4 +299,12 @@ mod tests {
         ]);
         assert_eq!(regression.interpolate(0.0), 3.0);
     }
+
+    #[test]
+    fn test_point_accessors() {
+        let point = Point { x: 1.0, y: 2.0 , weight : 3.0};
+        assert_eq!(point.x(), 1.0);
+        assert_eq!(point.y(), 2.0);
+        assert_eq!(point.weight(), 3.0);
+    }
 }
